@@ -81,6 +81,9 @@ class Recipe(BaseSlapRecipe):
     slave_instance_list = sorted(slave_instance_list,
                                  key=operator.itemgetter('slave_reference'))
 
+    # dict of used domains, only used to track duplicates
+    domain_dict = {}
+
     for slave_instance in slave_instance_list:
       backend_url = slave_instance.get("url", None)
       reference = slave_instance.get("slave_reference")
@@ -106,6 +109,12 @@ class Recipe(BaseSlapRecipe):
         domain = "%s.%s" % (reference.replace("-", "").lower(),
             frontend_domain_name)
 
+      if domain_dict.get(domain):
+        # This domain already has been processed, skip this new one
+        continue
+      else:
+        domain_dict[domain] = True
+
       # Define the URL where the instance will be available
       # WARNING: we use default ports (443, 80) here.
       slave_dict[reference] = "%s%s/" % (scheme, domain)
@@ -519,16 +528,21 @@ class Recipe(BaseSlapRecipe):
     self._createDirectory(cache_directory_location)
     self._createDirectory(mod_ssl_cache_location)
 
-    # Create "custom" apache configuration file if it does not exist.
-    # Note : This file won't be erased or changed when slapgrid is ran.
+    # Create "custom" apache configuration files if it does not exist.
+    # Note : Those files won't be erased or changed when slapgrid is ran.
     # It can be freely customized by node admin.
     custom_apache_configuration_directory = os.path.join(
         self.data_root_directory, 'apache-conf.d')
     self._createDirectory(custom_apache_configuration_directory)
+    # First one is included in the end of the apache configuration file
     custom_apache_configuration_file_location = os.path.join(
         custom_apache_configuration_directory, 'apache_frontend.custom.conf')
-    f = open(custom_apache_configuration_file_location, 'a')
-    f.close()
+    open(custom_apache_configuration_file_location, 'a')
+    # Second one is included in the virtualhost of apache configuration file
+    custom_apache_virtual_configuration_file_location = os.path.join(
+        custom_apache_configuration_directory,
+        'apache_frontend.virtualhost.custom.conf')
+    open(custom_apache_virtual_configuration_file_location, 'a')
 
     # Create backup of custom apache configuration
     backup_path = self.createBackupDirectory('custom_apache_conf_backup')
@@ -583,6 +597,7 @@ class Recipe(BaseSlapRecipe):
       https_port=port,
       plain_http_port=plain_http_port,
       custom_apache_conf=custom_apache_configuration_file_location,
+      custom_apache_virtualhost_conf=custom_apache_virtual_configuration_file_location,
     ))
 
     apache_conf_string = self.substituteTemplate(
