@@ -64,6 +64,10 @@ class Recipe(object):
       Set of IPv4 addresses.
     ipv6
       Set of IPv6 addresses.
+    ipv4_random
+      One of the IPv4 addresses.
+    ipv6_random
+      One of the IPv6 addresses.
     tap
       Set of TAP interfaces.
     configuration
@@ -109,6 +113,13 @@ class Recipe(object):
           # XXX: emit warning on unknown address type ?
       options['ipv4'] = ipv4_set
       options['ipv6'] = ipv6_set
+
+      # also export single ip values for those recipes that don't support sets.
+      if ipv4_set:
+          options['ipv4_random'] = list(ipv4_set)[0]
+      if ipv6_set:
+          options['ipv6_random'] = list(ipv6_set)[0]
+
       options['tap'] = tap_set
       options['configuration'] = parameter_dict
       match = self.OPTCRE_match
